@@ -1,6 +1,6 @@
 package MooseX::Constructor::AllErrors;
-BEGIN {
-  $MooseX::Constructor::AllErrors::VERSION = '0.017';
+{
+  $MooseX::Constructor::AllErrors::VERSION = '0.019';
 }
 
 use Moose ();
@@ -13,11 +13,6 @@ use MooseX::Constructor::AllErrors::Error::TypeConstraint;
 
 Moose::Exporter->setup_import_methods(
     base_class_roles => [ 'MooseX::Constructor::AllErrors::Role::Object' ],
-    class_metaroles => {
-        ($Moose::VERSION < 1.9900
-            ? (constructor => ['MooseX::Constructor::AllErrors::Role::Meta::Method::Constructor'])
-            : (class       => ['MooseX::Constructor::AllErrors::Role::Meta::Class'])),
-    },
 );
 
 1;
@@ -28,10 +23,6 @@ __END__
 
 MooseX::Constructor::AllErrors - capture all constructor errors
 
-=head1 VERSION
-
-version 0.017
-
 =head1 SYNOPSIS
 
   package MyClass;
@@ -66,6 +57,6 @@ L<Moose>
 
 This software is copyright (c) 2009 by Hans Dieter Pearcey. This is free
 software; you can redistribute it and/or modify it under the same terms as perl
-itself. 
+itself.
 
-=cut
\ No newline at end of file
+=cut
