@@ -1,11 +1,12 @@
 package MooseX::Constructor::AllErrors::Role::Object;
-BEGIN {
-  $MooseX::Constructor::AllErrors::Role::Object::VERSION = '0.017';
+{
+  $MooseX::Constructor::AllErrors::Role::Object::VERSION = '0.019';
 }
 
 use Moose::Role;
+use Try::Tiny;
 
-my $new_error = sub { 
+my $new_error = sub {
   my $class = shift;
   return "MooseX::Constructor::AllErrors::Error::$class"->new(@_);
 };
@@ -23,7 +24,7 @@ around BUILDARGS => sub {
   for my $attr (sort { $a->insertion_order <=> $b->insertion_order } $meta->get_all_attributes) {
     next unless defined( my $init_arg = $attr->init_arg );
 
-    if ($attr->is_required and 
+    if ($attr->is_required and
       ! $attr->is_lazy and
       ! $attr->has_default and
       ! $attr->has_builder and
@@ -39,13 +40,17 @@ around BUILDARGS => sub {
         ? $tc->coerce($args->{$init_arg})
         : $args->{$init_arg};
 
-    unless ($tc->check($value)) {
+    # use the attributes verify_against_type_constraint as that can be wrapped
+    # by other roles, namely MooseX::UndefTolerant
+    try {
+      $attr->verify_against_type_constraint($value);
+    }
+    catch {
       $error->add_error($new_error->(TypeConstraint => {
         attribute => $attr,
         data      => $value,
       }));
-      next;
-    }
+    };
   }
 
   if ($error->has_errors) {
